==> nextcloud-26.0.10.tgz: nextcloud/apps/updatenotification/l10n/fi.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} on saatavilla. Tarjolla on lisätietoja päivittämisestä.",
    "Channel updated" : "Päivityskanava päivitetty",
    "Web updater is disabled" : "Päivitys selaimen kautta on poissa käytöstä",
    "Update notifications" : "Päivitysilmoitukset",
    "The update server could not be reached since %d days to check for new updates." : "Päivityspalvelinta ei ole tavoitettu %d päivään; uusia päivityksiä ei voida tarkistaa.",
    "Please check the Nextcloud and server log files for errors." : "Tarkista Nextcloud- ja palvelinlokitiedostot virheiden osalta.",
    "Update to %1$s is available." : "Kohteen %1$s päivitys on saatavilla.",
    "Update to {serverAndVersion} is available." : "Päivitys {serverAndVersion} on saatavilla.",
    "Update for {app} to version %s is available." : "Sovelluksen {app} päivitys versioon %s on saatavilla.",
    "Update notification" : "Päivitysilmoitus",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Näyttää Nextcloudin päivitysilmoitukset ja tarjoaa SSO:n (Single Sign-On) päivittäjälle.",
    "Update" : "Päivitä",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Käyttämäsi versio ei ole enää tuettu. Varmista, että päivität tuettuun versioon mahdollisimman pian.",
    "Apps missing compatible version" : "Sovellukset, joista ei ole yhteensopivaa versiota",
    "View in store" : "Näytä kaupassa",
    "Apps with compatible version" : "Sovellukset, joista on yhteensopiva versio",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Huomioi, ettei päivitys selaimen kautta ole suositeltu yli 100 käyttäjän instansseissa! Tee sen sijaan päivitys komentoriviltä.",
    "Open updater" : "Avaa päivittäjä",
    "Download now" : "Lataa heti",
    "What's new?" : "Mitä uutta?",
    "View changelog" : "Näytä muutosloki",
    "The update check is not yet finished. Please refresh the page." : "Päivitystarkistus ei ole vielä valmis. Päivitä sivu.",
    "Your version is up to date." : "Versiosi on ajan tasalla.",
    "A non-default update server is in use to be checked for updates:" : "Käytössä on muu kuin oletusarvoinen päivityspalvelin, jota käytetään päivitysten tarkistamiseen:",
    "Update channel" : "Päivityskanava",
    "Current update channel:" : "Nykyinen päivityskanava:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Voit aina päivittää uudempaan versioon, mutta et voi palata aikaisempaan vakaaseen versioon.",
    "Notify members of the following groups about available updates:" : "Ilmoita seuraavien ryhmien jäsenille saatavilla olevista päivityksistä:",
    "No groups" : "Ei ryhmiä",
    "Only notifications for app updates are available." : "Vain ilmoitukset sovelluspäivityksistä on saatavilla.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Valittu päivityskanava tekee palvelimen omat ilmoitukset tarpeettomiksi.",
    "The selected update channel does not support updates of the server." : "Valittu päivityskanava ei tue palvelimen päivityksiä.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uusi versio on saatavilla: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Huomaa, että uuden julkaisun jälkeen päivitys näkyy vasta ensimmäisen pienemmän julkaisun jälkeen tai myöhemmin. Julkaisemme uusia versioita käyttäjillemme ajallisesti hajautetusti, ja joskus jätämme jonkin version väliin, jos ongelmia ilmenee. Lisätietoja päivityksistä ja julkaisukanavista osoitteessa {link}",
    "Checked on {lastCheckedDate}" : "Tarkistettu {lastCheckedDate}",
    "Checking apps for compatible versions" : "Tarkistetaan sovellusten yhteensopivat versiot ",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Varmista, ettei config.php-tiedosto aseta valintaa <samp>appstoreenabled</samp> arvoon false.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Kaikilla</strong> sovelluksilla on yhteensopiva versio saatavilla tälle Nextcloud-versiolle.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Yrityskäyttöön. Tarjoaa aina viimeisimmän korjaustason, mutta ei päivitä välittömästi seuraavaan pääversioon. Päivitys tapahtuu, kun Nextcloud GmbH on tehnyt lisävahvistuksia ja -testejä laajamittaisia ja kriittisiä käyttöönottoja varten. Tämä kanava on vain sopimusasiakkaiden käytettävissä, ja se tarjoaa Nextcloud Enterprise -paketin.",
    "Stable" : "Vakaa",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Viimeisin vakaa versio. Sopii säännölliseen käyttöön ja päivittyy aina uusimpaan pääversioon.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Esijulkaisuversio uusien toimintojen testaukseen, ei tuotantoympäristöille.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> sovelluksella on yhteensopiva versio saatavilla tälle Nextcloud-versiolle.","<strong>%n</strong> sovelluksella on yhteensopiva versio saatavilla tälle Nextcloud-versiolle."],
    "Please use the command line updater to update." : "Käytä komentorivipäivitintä päivittääksesi.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Voit vaihtaa päivityskanavan alapuolelta, se vaikuttaa myös sovellushallinnan sivuun. Jos vaihdat esimerkiksi beetakanavaan, sovellusten beetapäivityksiä tarjotaan sovellushallinnan sivun kautta.",
    "Update channel:" : "Päivityskanava:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.4.tgz: nextcloud/apps/updatenotification/l10n/fi.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} on saatavilla. Tarjolla on lisätietoja päivittämisestä.",
    "Channel updated" : "Päivityskanava päivitetty",
    "Web updater is disabled" : "Päivitys selaimen kautta on poissa käytöstä",
    "Update notifications" : "Päivitysilmoitukset",
    "The update server could not be reached since %d days to check for new updates." : "Päivityspalvelinta ei ole tavoitettu %d päivään; uusia päivityksiä ei voida tarkistaa.",
    "Please check the Nextcloud and server log files for errors." : "Tarkista Nextcloud- ja palvelinlokitiedostot virheiden osalta.",
    "Update to %1$s is available." : "Kohteen %1$s päivitys on saatavilla.",
    "Update to {serverAndVersion} is available." : "Päivitys {serverAndVersion} on saatavilla.",
    "Update for {app} to version %s is available." : "Sovelluksen {app} päivitys versioon %s on saatavilla.",
    "Update notification" : "Päivitysilmoitus",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Näyttää Nextcloudin päivitysilmoitukset ja tarjoaa SSO:n (Single Sign-On) päivittäjälle.",
    "Update" : "Päivitä",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Käyttämäsi versio ei ole enää tuettu. Varmista, että päivität tuettuun versioon mahdollisimman pian.",
    "Apps missing compatible version" : "Sovellukset, joista ei ole yhteensopivaa versiota",
    "View in store" : "Näytä kaupassa",
    "Apps with compatible version" : "Sovellukset, joista on yhteensopiva versio",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Huomioi, ettei päivitys selaimen kautta ole suositeltu yli 100 käyttäjän instansseissa! Tee sen sijaan päivitys komentoriviltä.",
    "Open updater" : "Avaa päivittäjä",
    "Download now" : "Lataa heti",
    "Please use the command line updater to update." : "Käytä komentorivipäivitintä päivittääksesi.",
    "What's new?" : "Mitä uutta?",
    "View changelog" : "Näytä muutosloki",
    "The update check is not yet finished. Please refresh the page." : "Päivitystarkistus ei ole vielä valmis. Päivitä sivu.",
    "Your version is up to date." : "Versiosi on ajan tasalla.",
    "A non-default update server is in use to be checked for updates:" : "Käytössä on muu kuin oletusarvoinen päivityspalvelin, jota käytetään päivitysten tarkistamiseen:",
    "Update channel" : "Päivityskanava",
    "Current update channel:" : "Nykyinen päivityskanava:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Voit aina päivittää uudempaan versioon, mutta et voi palata aikaisempaan vakaaseen versioon.",
    "Notify members of the following groups about available updates:" : "Ilmoita seuraavien ryhmien jäsenille saatavilla olevista päivityksistä:",
    "No groups" : "Ei ryhmiä",
    "Only notifications for app updates are available." : "Vain ilmoitukset sovelluspäivityksistä on saatavilla.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Valittu päivityskanava tekee palvelimen omat ilmoitukset tarpeettomiksi.",
    "The selected update channel does not support updates of the server." : "Valittu päivityskanava ei tue palvelimen päivityksiä.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uusi versio on saatavilla: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Huomaa, että uuden julkaisun jälkeen päivitys näkyy vasta ensimmäisen pienemmän julkaisun jälkeen tai myöhemmin. Julkaisemme uusia versioita käyttäjillemme ajallisesti hajautetusti, ja joskus jätämme jonkin version väliin, jos ongelmia ilmenee. Lisätietoja päivityksistä ja julkaisukanavista osoitteessa {link}",
    "Checked on {lastCheckedDate}" : "Tarkistettu {lastCheckedDate}",
    "Checking apps for compatible versions" : "Tarkistetaan sovellusten yhteensopivat versiot ",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Varmista, ettei config.php-tiedosto aseta valintaa <samp>appstoreenabled</samp> arvoon false.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Kaikilla</strong> sovelluksilla on yhteensopiva versio saatavilla tälle Nextcloud-versiolle.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Yrityskäyttöön. Tarjoaa aina viimeisimmän korjaustason, mutta ei päivitä välittömästi seuraavaan pääversioon. Päivitys tapahtuu, kun Nextcloud GmbH on tehnyt lisävahvistuksia ja -testejä laajamittaisia ja kriittisiä käyttöönottoja varten. Tämä kanava on vain sopimusasiakkaiden käytettävissä, ja se tarjoaa Nextcloud Enterprise -paketin.",
    "Stable" : "Vakaa",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Viimeisin vakaa versio. Sopii säännölliseen käyttöön ja päivittyy aina uusimpaan pääversioon.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Esijulkaisuversio uusien toimintojen testaukseen, ei tuotantoympäristöille.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> sovelluksella on yhteensopiva versio saatavilla tälle Nextcloud-versiolle.","<strong>%n</strong> sovelluksella on yhteensopiva versio saatavilla tälle Nextcloud-versiolle."],
    "Update for %1$s to version %2$s is available." : "Kohteen %1$s päivitys versioon %2$s on saatavilla.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Voit vaihtaa päivityskanavan alapuolelta, se vaikuttaa myös sovellushallinnan sivuun. Jos vaihdat esimerkiksi beetakanavaan, sovellusten beetapäivityksiä tarjotaan sovellushallinnan sivun kautta.",
    "Update channel:" : "Päivityskanava:"
},
"nplurals=2; plural=(n != 1);");
